power3d library

Classes

BoundingBoxConfig
Configuration for bounding box visualization.
LightingConfig
Configuration for a light source in the scene.
MaterialConfig
Configuration for overriding material properties of the model.
Power3D
A powerful 3D model viewer widget using Babylon.js.
Power3DAnimation
Represents the state of an animation in the 3D model.
Power3DController
Controller for programmatically managing the Power3D viewer.
Power3DData
Data structure representing a 3D model source.
Power3DState
State of the Power3D viewer.
Power3DTexture
Metadata representing a texture in the 3D scene.
SelectionConfig
Configuration for the object parts selection system.
SelectionShift
Positional offset for selected parts.
SelectionStyle
Visual style for selected or unselected parts of the model.
TextureUpdate
Request object to update texture properties.

Enums

BoundingBoxStyle
Styles for the bounding box visualization.
LightType
Types of lights supported in the scene.
Power3DSource
Source of the 3D model.
Power3DStatus
Loading status of the 3D model.
RotationDirection
Directions for automatic rotation of the model.
ShadingMode
Shading and rendering modes for the 3D scene.

Extensions

MaterialExtension on Power3DController
Materials and Lighting extension for Power3DController.
Power3DAnimationExtension on Power3DController
Extension on Power3DController for animation management.
SelectionExtension on Power3DController
Selection and Hierarchy extension for Power3DController.
TextureExtension on Power3DController
Texture Management extension for Power3DController.
ViewExtension on Power3DController
Camera and View extension for Power3DController.