ViewExtension extension
Camera and View extension for Power3DController.
Methods
-
resetScene(
) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Resets the entire scene to its initial state. Stops animations, clears selections, unhides parts, and resets camera. -
resetView(
) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Resets the camera to its default position and orientation. -
setCameraPosition(
{double? alpha, double? beta, double? radius}) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Sets the camera position and orientation. -
setLockPosition(
bool locked) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Locks or unlocks the object's position (panning). Iflocked, the object can be rotated and zoomed but not moved. -
takeScreenshot(
String savePath) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Takes a screenshot of the current 3D view and saves it tosavePath. Note:savePathmust include the file name and extension (e.g. 'path/to/shot.png'). -
toggleAutoRotate(
bool enabled) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
-
updateRotation(
{bool? enabled, double? speed, RotationDirection? direction, Duration? stopAfter}) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Updates the auto-rotation behavior of the camera. -
updateZoom(
{bool? enabled, double? min, double? max}) → Future< void> -
Available on Power3DController, provided by the ViewExtension extension
Updates the camera zoom limits and behavior.